@@ -20,12 +20,7 @@ from .export.update_scc_db import update
 from .readers.read_config import config
 from .debug import log_pack
 
-logger = logging.getLogger(__name__)
-logger = log_pack.scc_logger(logger)
-logger.setLevel('DEBUG')
-
-start_time = datetime.datetime.now()
-logger.info("------ Processing started on %s ------" % start_time)
+logger = logging.getLogger()
 
 def setup_directories(cfg):
     """ Check if the output folder exists. If not, create it."""
@@ -47,26 +42,31 @@ def main(args=None):
 ###############################################################################
 # O) Definitions
 ###############################################################################
+    log_pack.scc_logger(logger)
+    logger.setLevel('DEBUG')
+    start_time = datetime.datetime.now()
+    logger.info("--------------------------------")
+    logger.info("------ Processing started on %s ------" % start_time)
     
 #Ignores all warnings --> they are not printed in terminal
     warnings.filterwarnings('ignore')
 
-    logger.info("------ Parsing ltool options ")    
+    logger.info("Parsing ltool options ")    
     try:
         meas_id, cfg_path = parse_config()
     except Exception as e:
         logger.error("Error while parsing ltool options ")
         sys.exit(1)
-    logger.info("------ Options succesfully parsed ")    
+    logger.info("Options succesfully parsed ")    
    
 #Reading of the configuration file    
-    logger.info("------ Parsing the configuration file ")    
+    logger.info("Parsing the configuration file ")    
     try:
         cfg = config(cfg_path)
     except Exception as e:
         logger.error("Error while reading the configuration file ")
         sys.exit(2)
-    logger.info("------ Configuration file succesfully parsed ")    
+    logger.info("Configuration file succesfully parsed ")    
     
 # Make directories if they do not exist
     try:
@@ -85,13 +85,14 @@ def main(args=None):
     margin = 0.63
     
 # Get array of input files from an scc database query
-    logger.info("------ Quering the measurement paths in the SCC database ")
+    logger.info("------ Processing started on %s ------" % start_time)
+    logger.info("Quering the measurement paths in the SCC database ")
     try:
         files, rpath, exts, alphas, det_lims, ids = database(meas_id, cfg = cfg)
     except Exception as e:
         logger.error("Error while executing a measurement ID query in the SCC database ")
         sys.exit(4)                
-    logger.info("------ Measurement paths succesfully collected ")    
+    logger.info("Measurement paths succesfully collected ")    
     
 ###############################################################################
 # A) Preprocessing
@@ -101,11 +102,11 @@ def main(args=None):
     logger.info("------ Section A: Reading the SCC files ")
     try:
         dt_start_arr, alt_arr, prod_arr, metadata = \
-            read_scc_db(files, end_fill = alphas, log = logger)
+            read_scc_db(files, end_fill = alphas)
     except Exception as e:
         logger.error("Error while reading the SCC files ")
         sys.exit(5)   
-    logger.info("------ SCC files succesfully read ")
+    logger.info("       All SCC files succesfully read ")
     
 ###############################################################################
 # B) Geometrical retrievals
@@ -116,7 +117,7 @@ def main(args=None):
     list_dates = []
 
     for i in range(0, len(files)):
-        logger.info(f"------ Proccessing file: {os.path.basename(files[i])} ")
+        logger.info(f"       Proccessing file: {os.path.basename(files[i])} ")
 
         norm = prod_arr[i]/det_lims[i]
         
@@ -129,7 +130,7 @@ def main(args=None):
         except Exception as e:
             logger.error("Error while identifying layer boundaries ")
             sys.exit(6)  
-        logger.info("------ Potential layer boundaries succesfully identified ")
+        logger.info("       Potential layer boundaries succesfully identified ")
 
 # B.2) Use base and top to the profile to extract aditional 
 # geometrical properties
@@ -138,7 +139,7 @@ def main(args=None):
         except Exception as e:
             logger.error("Error calculating layer properties ")
             sys.exit(7)  
-        logger.info("------ Layer properties succesfully calculated ")
+        logger.info("       Layer properties succesfully calculated ")
         
 # B.3) Filter out irregular features
         try:
@@ -146,13 +147,15 @@ def main(args=None):
         except Exception as e:
             logger.error("Error while filtering out irregular layers ")
             sys.exit(8)  
-        logger.info("------ Irregular layers succesfully filtered out ")
+        logger.info("       Irregular layers succesfully filtered out ")
     
         
 ###############################################################################
 # C) Exporting
-############################################################################### 
-        logger.info("------ Section C: Exporting layer properties ")
+###############################################################################
+        if i == 0: 
+            logger.info("------ Section C: Exporting layer properties ")
+            
         if len(geom) > 0:
 # C.1) Export to netcdf
 # C.1.i) Netcdf filename
@@ -161,7 +164,7 @@ def main(args=None):
             except Exception as e:
                 logger.error("Error while creating the netcdf filename ")
                 sys.exit(9)  
-            logger.info("------ Netcdf filename succesfully created ")
+            logger.info("       Netcdf filename succesfully created ")
             
 # C.1.ii) Netcdf file        
             try:
@@ -171,13 +174,13 @@ def main(args=None):
             except Exception as e:
                 logger.error("Error while creating the netcdf files ")
                 sys.exit(10)
-            logger.info("------ Exporting in NetCDF format succesfully completed ")
+            logger.info("       Exporting in NetCDF format succesfully completed ")
             
 # C.2) Save in lists
             list_dates.append(dt_start_arr[i])
             list_geom.append(geom)
             list_geom_dts.append(geom_dts)
-            logger.info("------ Exporting in python list format succesfully completed ")
+            logger.info("       Exporting in python list format succesfully completed ")
     
 # C.3) Update the database
             try:
@@ -186,25 +189,19 @@ def main(args=None):
             except Exception as e:
                 logger.error("Error while updating the scc database ")
                 sys.exit(11)         
-            logger.info("------ SCC database succesfully updated ")
+            logger.info("       SCC database succesfully updated ")
         else:
-            logger.warning("------ No layers were identified for this measurement! ")
-
-    return(list_dates, list_geom, list_geom_dts, cfg)
-
-# Execute main
-if __name__ == "__main__":
-    logger.info("------ Calling the main module ")
-    list_dates, list_geom, list_geom_dts, cfg = main()
+            logger.warning("       No layers were identified for this measurement! ")
 
 ###############################################################################
 # End of Program
 ############################################################################### 
-stop_time = datetime.datetime.now()
-duration = stop_time - start_time
-
-logger.info("------ Processing finished on %s ------" % stop_time)
-logger.info("------ Total duration: %s ------" % duration)
-logging.shutdown()
-
-sys.exit(0)
\ No newline at end of file
+    stop_time = datetime.datetime.now()
+    duration = stop_time - start_time
+    
+    logger.info("------ Processing finished on %s ------" % stop_time)
+    logger.info("------ Total duration: %s ------" % duration)
+    logger.info("--------------------------------")
+    logging.shutdown()
+    
+    sys.exit(0)
\ No newline at end of file
